=======
History
=======

0.4.0
-----

* DONE: (feature) nested milestones and tasks
* DONE: (refactor) consider remove get_task_type registration for List type
* DONE: (feature) get_critical_path implementation in GanttDrawer (consider refactoring PertDrawer out?)
* DONE: (feature) when task depends on milestone, replace milestone dependency with the last critical task in this milestone but do not make this task critical globally in the project
* release on pypi (2022-09-29)


0.3.0
-----

* getting used to bumpversion

0.2.0
-----

* getting used to pypi

0.1.0 (2022-09-20)
------------------

* botched First release on PyPI.
